@@ -16,7 +16,7 @@ our @EXPORT_OK = qw(
     is_hash     every    noop        identity
 );
 
-our $VERSION = '0.05';
+our $VERSION = '0.07';
 
 use constant ARG_PLACE_HOLDER => {};
 
@@ -412,10 +412,6 @@ sub spread {
 
 Sub::Fp - A Clojure / Python Toolz / Lodash inspired Functional Utility Library
 
-=head1 VERSION
-
-Version 0.02
-
 =cut
 
 =head1 SYNOPSIS
@@ -426,6 +422,19 @@ concise code.
 
 =head1 SUBROUTINES/METHODS
 
+=head1 EXPORT
+
+    incr        reduces  flatten
+    drop_right  drop     take_right  take
+    assoc       maps     decr         chain
+    first       end      subarray    partial
+    __          find     filter      some
+    none        uniq     bool        spread
+    len         to_keys  to_vals     is_array
+    is_hash     every    noop        identity
+
+=cut
+
 =head2 incr
 
 Increments the supplied number by 1
@@ -485,7 +494,7 @@ The iteratee is invoked with four arguments:
     reduces(sub {
         my ($accum, $num) = @_;
         return {
-            %{ $accum },
+            spread($accum),
             key => $num,
         }
     }, {}, [1,2,3]);
@@ -670,7 +679,7 @@ A function that returns its first argument
 
     # 1
 
-    # identity([1,2,3])
+    identity([1,2,3])
 
     # [1,2,3]
 
@@ -1028,22 +1037,6 @@ as the first argument to the proceding function
 
 =cut
 
-=head1 EXPORT
-
-A list of functions that can be exported.  You can delete this section
-if you don't export anything, such as for a purely object-oriented module.
-
-    incr        reduces  flatten
-    drop_right  drop     take_right  take
-    assoc       maps     decr         chain
-    first       end      subarray    partial
-    __          find     filter      some
-    none        uniq     bool        spread
-    len         to_keys  to_vals     is_array
-    is_hash     every    noop        identity
-
-=cut
-
 =head1 AUTHOR
 
 Kristopher C. Paulsen, C<< <kristopherpaulsen+cpan at gmail.com> >>
@@ -1089,43 +1082,13 @@ L<https://metacpan.org/release/Sub-Fp>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2018 Kristopher C. Paulsen.
+MIT
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of the the Artistic License (2.0). You may obtain a
-copy of the full license at:
+Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 
-L<http://www.perlfoundation.org/artistic_license_2_0>
+The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 
-Any use, modification, and distribution of the Standard or Modified
-Versions is governed by this Artistic License. By using, modifying or
-distributing the Package, you accept this license. Do not use, modify,
-or distribute the Package, if you do not accept this license.
-
-If your Modified Version has been derived from a Modified Version made
-by someone other than you, you are nevertheless required to ensure that
-your Modified Version complies with the requirements of this license.
-
-This license does not grant you the right to use any trademark, service
-mark, tradename, or logo of the Copyright Holder.
-
-This license includes the non-exclusive, worldwide, free-of-charge
-patent license to make, have made, use, offer to sell, sell, import and
-otherwise transfer the Package with respect to any patent claims
-licensable by the Copyright Holder that are necessarily infringed by the
-Package. If you institute patent litigation (including a cross-claim or
-counterclaim) against any party alleging that the Package constitutes
-direct or contributory patent infringement, then this Artistic License
-to you shall terminate on the date that such litigation is filed.
-
-Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
-AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
-THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
-YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
-CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
-EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
 =cut
